@@ -45,9 +45,13 @@
 #include "../__utility/in_place.h"
 #include "../__utility/move.h"
 
-#if defined(_LIBCUDACXX_USE_PRAGMA_GCC_SYSTEM_HEADER)
-#pragma GCC system_header
-#endif
+#if defined(_CCCL_IMPLICIT_SYSTEM_HEADER_GCC)
+#  pragma GCC system_header
+#elif defined(_CCCL_IMPLICIT_SYSTEM_HEADER_CLANG)
+#  pragma clang system_header
+#elif defined(_CCCL_IMPLICIT_SYSTEM_HEADER_MSVC)
+#  pragma system_header
+#endif // no system header
 
 #if _LIBCUDACXX_STD_VER > 11
 
@@ -70,12 +74,12 @@ union __expected_union_t {
   struct __empty_t {};
 
   _LIBCUDACXX_TEMPLATE(class _Tp2 = _Tp)
-    (requires _LIBCUDACXX_TRAIT(is_default_constructible, _Tp2))
+    _LIBCUDACXX_REQUIRES( _LIBCUDACXX_TRAIT(is_default_constructible, _Tp2))
   _LIBCUDACXX_INLINE_VISIBILITY constexpr
   __expected_union_t() noexcept(_LIBCUDACXX_TRAIT(is_nothrow_default_constructible, _Tp2)) : __val_() {}
 
   _LIBCUDACXX_TEMPLATE(class _Tp2 = _Tp)
-    (requires (!_LIBCUDACXX_TRAIT(is_default_constructible, _Tp2)))
+    _LIBCUDACXX_REQUIRES( (!_LIBCUDACXX_TRAIT(is_default_constructible, _Tp2)))
   _LIBCUDACXX_INLINE_VISIBILITY constexpr
   __expected_union_t() noexcept : __empty_() {}
 
@@ -117,12 +121,12 @@ union __expected_union_t<_Tp, _Err, true> {
   struct __empty_t {};
 
   _LIBCUDACXX_TEMPLATE(class _Tp2 = _Tp)
-    (requires _LIBCUDACXX_TRAIT(is_default_constructible, _Tp2))
+    _LIBCUDACXX_REQUIRES( _LIBCUDACXX_TRAIT(is_default_constructible, _Tp2))
   _LIBCUDACXX_INLINE_VISIBILITY constexpr
   __expected_union_t() noexcept(_LIBCUDACXX_TRAIT(is_nothrow_default_constructible, _Tp2)) : __val_() {}
 
   _LIBCUDACXX_TEMPLATE(class _Tp2 = _Tp)
-    (requires (!_LIBCUDACXX_TRAIT(is_default_constructible, _Tp2)))
+    _LIBCUDACXX_REQUIRES( (!_LIBCUDACXX_TRAIT(is_default_constructible, _Tp2)))
   _LIBCUDACXX_INLINE_VISIBILITY constexpr
   __expected_union_t() noexcept : __empty_() {}
 
@@ -380,7 +384,7 @@ struct __expected_storage : __expected_destruct<_Tp, _Err>
 #endif // !_LIBCUDACXX_COMPILER_NVRTC || nvcc >= 11.3
 
   _LIBCUDACXX_TEMPLATE(class _T1, class _T2, class... _Args)
-    (requires _LIBCUDACXX_TRAIT(is_nothrow_constructible, _T1, _Args...))
+    _LIBCUDACXX_REQUIRES( _LIBCUDACXX_TRAIT(is_nothrow_constructible, _T1, _Args...))
   static _LIBCUDACXX_INLINE_VISIBILITY _LIBCUDACXX_CONSTEXPR_AFTER_CXX17
   void __reinit_expected(_T1& __newval, _T2& __oldval, _Args&&... __args) noexcept {
     _CUDA_VSTD::__destroy_at(_CUDA_VSTD::addressof(__oldval));
@@ -388,7 +392,7 @@ struct __expected_storage : __expected_destruct<_Tp, _Err>
   }
 
   _LIBCUDACXX_TEMPLATE(class _T1, class _T2, class... _Args)
-    (requires (!_LIBCUDACXX_TRAIT(is_nothrow_constructible, _T1, _Args...)) _LIBCUDACXX_AND
+    _LIBCUDACXX_REQUIRES( (!_LIBCUDACXX_TRAIT(is_nothrow_constructible, _T1, _Args...)) _LIBCUDACXX_AND
                 _LIBCUDACXX_TRAIT(is_nothrow_move_constructible, _T1)
     )
   static _LIBCUDACXX_INLINE_VISIBILITY _LIBCUDACXX_CONSTEXPR_AFTER_CXX17
@@ -399,7 +403,7 @@ struct __expected_storage : __expected_destruct<_Tp, _Err>
   }
 
   _LIBCUDACXX_TEMPLATE(class _T1, class _T2, class... _Args)
-    (requires (!_LIBCUDACXX_TRAIT(is_nothrow_constructible, _T1, _Args...)) _LIBCUDACXX_AND
+    _LIBCUDACXX_REQUIRES( (!_LIBCUDACXX_TRAIT(is_nothrow_constructible, _T1, _Args...)) _LIBCUDACXX_AND
               (!_LIBCUDACXX_TRAIT(is_nothrow_move_constructible, _T1))
     )
   static _LIBCUDACXX_INLINE_VISIBILITY _LIBCUDACXX_CONSTEXPR_AFTER_CXX17
@@ -416,7 +420,7 @@ struct __expected_storage : __expected_destruct<_Tp, _Err>
   }
 
   _LIBCUDACXX_TEMPLATE(class _Err2 = _Err)
-    (requires _LIBCUDACXX_TRAIT(is_nothrow_move_constructible, _Err2))
+    _LIBCUDACXX_REQUIRES( _LIBCUDACXX_TRAIT(is_nothrow_move_constructible, _Err2))
   static _LIBCUDACXX_INLINE_VISIBILITY _LIBCUDACXX_CONSTEXPR_AFTER_CXX17
   void __swap_val_unex_impl(__expected_storage<_Tp, _Err2>& __with_val, __expected_storage& __with_err) {
     _Err __tmp(_CUDA_VSTD::move(__with_err.__union_.__unex_));
@@ -433,7 +437,7 @@ struct __expected_storage : __expected_destruct<_Tp, _Err>
   }
 
   _LIBCUDACXX_TEMPLATE(class _Err2 = _Err)
-    (requires (!_LIBCUDACXX_TRAIT(is_nothrow_move_constructible, _Err2)))
+    _LIBCUDACXX_REQUIRES( (!_LIBCUDACXX_TRAIT(is_nothrow_move_constructible, _Err2)))
   static _LIBCUDACXX_INLINE_VISIBILITY _LIBCUDACXX_CONSTEXPR_AFTER_CXX17
   void __swap_val_unex_impl(__expected_storage<_Tp, _Err2>& __with_val, __expected_storage& __with_err) {
     static_assert(_LIBCUDACXX_TRAIT(is_nothrow_move_constructible, _Tp),
