@@ -31,9 +31,13 @@
 #include "../__utility/swap.h"
 #include "../cstdint"
 
-#if defined(_LIBCUDACXX_USE_PRAGMA_GCC_SYSTEM_HEADER)
-#pragma GCC system_header
-#endif
+#if defined(_CCCL_IMPLICIT_SYSTEM_HEADER_GCC)
+#  pragma GCC system_header
+#elif defined(_CCCL_IMPLICIT_SYSTEM_HEADER_CLANG)
+#  pragma clang system_header
+#elif defined(_CCCL_IMPLICIT_SYSTEM_HEADER_MSVC)
+#  pragma system_header
+#endif // no system header
 
 #ifndef __cuda_std__
 
@@ -281,7 +285,7 @@ struct __scalar_hash<_Tp, 0>
     : public __unary_function<_Tp, size_t>
 {
     _LIBCUDACXX_INLINE_VISIBILITY
-    size_t operator()(_Tp __v) const _NOEXCEPT
+    size_t operator()(_Tp __v) const noexcept
     {
         union
         {
@@ -299,7 +303,7 @@ struct __scalar_hash<_Tp, 1>
     : public __unary_function<_Tp, size_t>
 {
     _LIBCUDACXX_INLINE_VISIBILITY
-    size_t operator()(_Tp __v) const _NOEXCEPT
+    size_t operator()(_Tp __v) const noexcept
     {
         union
         {
@@ -316,7 +320,7 @@ struct __scalar_hash<_Tp, 2>
     : public __unary_function<_Tp, size_t>
 {
     _LIBCUDACXX_INLINE_VISIBILITY
-    size_t operator()(_Tp __v) const _NOEXCEPT
+    size_t operator()(_Tp __v) const noexcept
     {
         union
         {
@@ -337,7 +341,7 @@ struct __scalar_hash<_Tp, 3>
     : public __unary_function<_Tp, size_t>
 {
     _LIBCUDACXX_INLINE_VISIBILITY
-    size_t operator()(_Tp __v) const _NOEXCEPT
+    size_t operator()(_Tp __v) const noexcept
     {
         union
         {
@@ -359,7 +363,7 @@ struct __scalar_hash<_Tp, 4>
     : public __unary_function<_Tp, size_t>
 {
     _LIBCUDACXX_INLINE_VISIBILITY
-    size_t operator()(_Tp __v) const _NOEXCEPT
+    size_t operator()(_Tp __v) const noexcept
     {
         union
         {
@@ -383,7 +387,7 @@ struct _PairT {
 };
 
 _LIBCUDACXX_INLINE_VISIBILITY
-inline size_t __hash_combine(size_t __lhs, size_t __rhs) _NOEXCEPT {
+inline size_t __hash_combine(size_t __lhs, size_t __rhs) noexcept {
     typedef __scalar_hash<_PairT> _HashT;
     const _PairT __p = {__lhs, __rhs};
     return _HashT()(__p);
@@ -394,7 +398,7 @@ struct _LIBCUDACXX_TEMPLATE_VIS hash<_Tp*>
     : public __unary_function<_Tp*, size_t>
 {
     _LIBCUDACXX_INLINE_VISIBILITY
-    size_t operator()(_Tp* __v) const _NOEXCEPT
+    size_t operator()(_Tp* __v) const noexcept
     {
         union
         {
@@ -411,7 +415,7 @@ struct _LIBCUDACXX_TEMPLATE_VIS hash<bool>
     : public __unary_function<bool, size_t>
 {
     _LIBCUDACXX_INLINE_VISIBILITY
-    size_t operator()(bool __v) const _NOEXCEPT {return static_cast<size_t>(__v);}
+    size_t operator()(bool __v) const noexcept {return static_cast<size_t>(__v);}
 };
 
 template <>
@@ -419,7 +423,7 @@ struct _LIBCUDACXX_TEMPLATE_VIS hash<char>
     : public __unary_function<char, size_t>
 {
     _LIBCUDACXX_INLINE_VISIBILITY
-    size_t operator()(char __v) const _NOEXCEPT {return static_cast<size_t>(__v);}
+    size_t operator()(char __v) const noexcept {return static_cast<size_t>(__v);}
 };
 
 template <>
@@ -427,7 +431,7 @@ struct _LIBCUDACXX_TEMPLATE_VIS hash<signed char>
     : public __unary_function<signed char, size_t>
 {
     _LIBCUDACXX_INLINE_VISIBILITY
-    size_t operator()(signed char __v) const _NOEXCEPT {return static_cast<size_t>(__v);}
+    size_t operator()(signed char __v) const noexcept {return static_cast<size_t>(__v);}
 };
 
 template <>
@@ -435,7 +439,7 @@ struct _LIBCUDACXX_TEMPLATE_VIS hash<unsigned char>
     : public __unary_function<unsigned char, size_t>
 {
     _LIBCUDACXX_INLINE_VISIBILITY
-    size_t operator()(unsigned char __v) const _NOEXCEPT {return static_cast<size_t>(__v);}
+    size_t operator()(unsigned char __v) const noexcept {return static_cast<size_t>(__v);}
 };
 
 #ifndef _LIBCUDACXX_HAS_NO_UNICODE_CHARS
@@ -444,7 +448,7 @@ struct _LIBCUDACXX_TEMPLATE_VIS hash<char16_t>
     : public __unary_function<char16_t, size_t>
 {
     _LIBCUDACXX_INLINE_VISIBILITY
-    size_t operator()(char16_t __v) const _NOEXCEPT {return static_cast<size_t>(__v);}
+    size_t operator()(char16_t __v) const noexcept {return static_cast<size_t>(__v);}
 };
 
 template <>
@@ -452,7 +456,7 @@ struct _LIBCUDACXX_TEMPLATE_VIS hash<char32_t>
     : public __unary_function<char32_t, size_t>
 {
     _LIBCUDACXX_INLINE_VISIBILITY
-    size_t operator()(char32_t __v) const _NOEXCEPT {return static_cast<size_t>(__v);}
+    size_t operator()(char32_t __v) const noexcept {return static_cast<size_t>(__v);}
 };
 #endif  // _LIBCUDACXX_HAS_NO_UNICODE_CHARS
 
@@ -462,7 +466,7 @@ struct _LIBCUDACXX_TEMPLATE_VIS hash<wchar_t>
     : public __unary_function<wchar_t, size_t>
 {
     _LIBCUDACXX_INLINE_VISIBILITY
-    size_t operator()(wchar_t __v) const _NOEXCEPT {return static_cast<size_t>(__v);}
+    size_t operator()(wchar_t __v) const noexcept {return static_cast<size_t>(__v);}
 };
 #endif // _LIBCUDACXX_HAS_NO_WIDE_CHARACTERS
 
@@ -471,7 +475,7 @@ struct _LIBCUDACXX_TEMPLATE_VIS hash<short>
     : public __unary_function<short, size_t>
 {
     _LIBCUDACXX_INLINE_VISIBILITY
-    size_t operator()(short __v) const _NOEXCEPT {return static_cast<size_t>(__v);}
+    size_t operator()(short __v) const noexcept {return static_cast<size_t>(__v);}
 };
 
 template <>
@@ -479,7 +483,7 @@ struct _LIBCUDACXX_TEMPLATE_VIS hash<unsigned short>
     : public __unary_function<unsigned short, size_t>
 {
     _LIBCUDACXX_INLINE_VISIBILITY
-    size_t operator()(unsigned short __v) const _NOEXCEPT {return static_cast<size_t>(__v);}
+    size_t operator()(unsigned short __v) const noexcept {return static_cast<size_t>(__v);}
 };
 
 template <>
@@ -487,7 +491,7 @@ struct _LIBCUDACXX_TEMPLATE_VIS hash<int>
     : public __unary_function<int, size_t>
 {
     _LIBCUDACXX_INLINE_VISIBILITY
-    size_t operator()(int __v) const _NOEXCEPT {return static_cast<size_t>(__v);}
+    size_t operator()(int __v) const noexcept {return static_cast<size_t>(__v);}
 };
 
 template <>
@@ -495,7 +499,7 @@ struct _LIBCUDACXX_TEMPLATE_VIS hash<unsigned int>
     : public __unary_function<unsigned int, size_t>
 {
     _LIBCUDACXX_INLINE_VISIBILITY
-    size_t operator()(unsigned int __v) const _NOEXCEPT {return static_cast<size_t>(__v);}
+    size_t operator()(unsigned int __v) const noexcept {return static_cast<size_t>(__v);}
 };
 
 template <>
@@ -503,7 +507,7 @@ struct _LIBCUDACXX_TEMPLATE_VIS hash<long>
     : public __unary_function<long, size_t>
 {
     _LIBCUDACXX_INLINE_VISIBILITY
-    size_t operator()(long __v) const _NOEXCEPT {return static_cast<size_t>(__v);}
+    size_t operator()(long __v) const noexcept {return static_cast<size_t>(__v);}
 };
 
 template <>
@@ -511,7 +515,7 @@ struct _LIBCUDACXX_TEMPLATE_VIS hash<unsigned long>
     : public __unary_function<unsigned long, size_t>
 {
     _LIBCUDACXX_INLINE_VISIBILITY
-    size_t operator()(unsigned long __v) const _NOEXCEPT {return static_cast<size_t>(__v);}
+    size_t operator()(unsigned long __v) const noexcept {return static_cast<size_t>(__v);}
 };
 
 template <>
@@ -547,7 +551,7 @@ struct _LIBCUDACXX_TEMPLATE_VIS hash<float>
     : public __scalar_hash<float>
 {
     _LIBCUDACXX_INLINE_VISIBILITY
-    size_t operator()(float __v) const _NOEXCEPT
+    size_t operator()(float __v) const noexcept
     {
         // -0.0 and 0.0 should return same hash
        if (__v == 0.0f)
@@ -561,7 +565,7 @@ struct _LIBCUDACXX_TEMPLATE_VIS hash<double>
     : public __scalar_hash<double>
 {
     _LIBCUDACXX_INLINE_VISIBILITY
-    size_t operator()(double __v) const _NOEXCEPT
+    size_t operator()(double __v) const noexcept
     {
         // -0.0 and 0.0 should return same hash
        if (__v == 0.0)
@@ -575,7 +579,7 @@ struct _LIBCUDACXX_TEMPLATE_VIS hash<long double>
     : public __scalar_hash<long double>
 {
     _LIBCUDACXX_INLINE_VISIBILITY
-    size_t operator()(long double __v) const _NOEXCEPT
+    size_t operator()(long double __v) const noexcept
     {
         // -0.0 and 0.0 should return same hash
         if (__v == 0.0L)
@@ -625,7 +629,7 @@ struct _LIBCUDACXX_TEMPLATE_VIS __enum_hash
     : public __unary_function<_Tp, size_t>
 {
     _LIBCUDACXX_INLINE_VISIBILITY
-    size_t operator()(_Tp __v) const _NOEXCEPT
+    size_t operator()(_Tp __v) const noexcept
     {
         typedef typename underlying_type<_Tp>::type type;
         return hash<type>()(static_cast<type>(__v));
@@ -650,13 +654,12 @@ struct _LIBCUDACXX_TEMPLATE_VIS hash<nullptr_t>
   : public __unary_function<nullptr_t, size_t>
 {
   _LIBCUDACXX_INLINE_VISIBILITY
-  size_t operator()(nullptr_t) const _NOEXCEPT {
+  size_t operator()(nullptr_t) const noexcept {
     return 662607004ull;
   }
 };
 #endif
 
-#ifndef _LIBCUDACXX_CXX03_LANG
 template <class _Key, class _Hash>
 using __check_hash_requirements _LIBCUDACXX_NODEBUG_TYPE = integral_constant<bool,
     is_copy_constructible<_Hash>::value &&
@@ -683,8 +686,6 @@ template <class _Type, class ...>
 using __enable_hash_helper _LIBCUDACXX_NODEBUG_TYPE = _Type;
 #endif
 
-#endif // !_LIBCUDACXX_CXX03_LANG
-
 _LIBCUDACXX_END_NAMESPACE_STD
 
 #endif // __cuda_std__
