@@ -11,29 +11,32 @@
 #define _LIBCUDACXX___TUPLE_MAKE_TUPLE_INDICES_H
 
 #ifndef __cuda_std__
-#include <__config>
+#  include <__config>
 #endif // __cuda_std__
 
 #include "../__utility/integer_sequence.h"
 #include "../cstddef"
 
-#if defined(_LIBCUDACXX_USE_PRAGMA_GCC_SYSTEM_HEADER)
-#pragma GCC system_header
-#endif
-
-#ifndef _LIBCUDACXX_CXX03_LANG
+#if defined(_CCCL_IMPLICIT_SYSTEM_HEADER_GCC)
+#  pragma GCC system_header
+#elif defined(_CCCL_IMPLICIT_SYSTEM_HEADER_CLANG)
+#  pragma clang system_header
+#elif defined(_CCCL_IMPLICIT_SYSTEM_HEADER_MSVC)
+#  pragma system_header
+#endif // no system header
 
 _LIBCUDACXX_BEGIN_NAMESPACE_STD
 
 template <size_t _Ep, size_t _Sp = 0>
 struct __make_tuple_indices
 {
-    static_assert(_Sp <= _Ep, "__make_tuple_indices input error");
-    typedef __make_indices_imp<_Ep, _Sp> type;
+  static_assert(_Sp <= _Ep, "__make_tuple_indices input error");
+  typedef __make_indices_imp<_Ep, _Sp> type;
 };
 
+template <size_t _Ep, size_t _Sp = 0>
+using __make_tuple_indices_t = typename __make_tuple_indices<_Ep, _Sp>::type;
+
 _LIBCUDACXX_END_NAMESPACE_STD
 
-#endif // _LIBCUDACXX_CXX03_LANG
-
 #endif // _LIBCUDACXX___TUPLE_MAKE_TUPLE_INDICES_H
