@@ -23,6 +23,14 @@
 #pragma once
 
 #include <thrust/detail/config.h>
+
+#if defined(_CCCL_IMPLICIT_SYSTEM_HEADER_GCC)
+#  pragma GCC system_header
+#elif defined(_CCCL_IMPLICIT_SYSTEM_HEADER_CLANG)
+#  pragma clang system_header
+#elif defined(_CCCL_IMPLICIT_SYSTEM_HEADER_MSVC)
+#  pragma system_header
+#endif // no system header
 #include <thrust/detail/vector_base.h>
 #include <thrust/device_allocator.h>
 
@@ -203,14 +211,14 @@ template<typename T, typename Alloc = thrust::device_allocator<T> >
      */
     device_vector(std::initializer_list<T> il)
       :Parent(il) {}
-      
+
     /*! This constructor builds a \p device_vector from an intializer_list.
      *  \param il The intializer_list.
      *  \param alloc The allocator to use by this device_vector.
      */
     device_vector(std::initializer_list<T> il, const Alloc &alloc)
       :Parent(il, alloc) {}
-      
+
     /*! Assign an \p intializer_list with a matching element type
      *  \param il The intializer_list.
      */
