@@ -22,6 +22,14 @@
 #pragma once
 
 #include <thrust/detail/config.h>
+
+#if defined(_CCCL_IMPLICIT_SYSTEM_HEADER_GCC)
+#  pragma GCC system_header
+#elif defined(_CCCL_IMPLICIT_SYSTEM_HEADER_CLANG)
+#  pragma clang system_header
+#elif defined(_CCCL_IMPLICIT_SYSTEM_HEADER_MSVC)
+#  pragma system_header
+#endif // no system header
 #include <thrust/detail/execution_policy.h>
 
 THRUST_NAMESPACE_BEGIN
@@ -38,16 +46,16 @@ THRUST_NAMESPACE_BEGIN
 
 /*! \p inclusive_scan computes an inclusive prefix sum operation. The
  *  term 'inclusive' means that each result includes the corresponding
- *  input operand in the partial sum. More precisely, <tt>*first</tt> is 
- *  assigned to <tt>*result</tt> and the sum of <tt>*first</tt> and 
- *  <tt>*(first + 1)</tt> is assigned to <tt>*(result + 1)</tt>, and so on. 
- *  This version of \p inclusive_scan assumes plus as the associative operator.  
- *  When the input and output sequences are the same, the scan is performed 
+ *  input operand in the partial sum. More precisely, <tt>*first</tt> is
+ *  assigned to <tt>*result</tt> and the sum of <tt>*first</tt> and
+ *  <tt>*(first + 1)</tt> is assigned to <tt>*(result + 1)</tt>, and so on.
+ *  This version of \p inclusive_scan assumes plus as the associative operator.
+ *  When the input and output sequences are the same, the scan is performed
  *  in-place.
  *
  *  \p inclusive_scan is similar to \c std::partial_sum in the STL.  The primary
  *  difference between the two functions is that \c std::partial_sum guarantees
- *  a serial summation order, while \p inclusive_scan requires associativity of 
+ *  a serial summation order, while \p inclusive_scan requires associativity of
  *  the binary operation to parallelize the prefix sum.
  *
  *  Results are not deterministic for pseudo-associative operators (e.g.,
@@ -55,7 +63,7 @@ THRUST_NAMESPACE_BEGIN
  *  operators may vary from run to run.
  *
  *  The algorithm's execution is parallelized as determined by \p exec.
- *    
+ *
  *  \param exec The execution policy to use for parallelization.
  *  \param first The beginning of the input sequence.
  *  \param last The end of the input sequence.
@@ -81,7 +89,7 @@ THRUST_NAMESPACE_BEGIN
  *  #include <thrust/scan.h>
  *  #include <thrust/execution_policy.h>
  *  ...
- *  
+ *
  *  int data[6] = {1, 0, 2, 2, 1, 3};
  *
  *  thrust::inclusive_scan(thrust::host, data, data + 6, data); // in-place scan
@@ -104,16 +112,16 @@ __host__ __device__
 
 /*! \p inclusive_scan computes an inclusive prefix sum operation. The
  *  term 'inclusive' means that each result includes the corresponding
- *  input operand in the partial sum. More precisely, <tt>*first</tt> is 
- *  assigned to <tt>*result</tt> and the sum of <tt>*first</tt> and 
- *  <tt>*(first + 1)</tt> is assigned to <tt>*(result + 1)</tt>, and so on. 
- *  This version of \p inclusive_scan assumes plus as the associative operator.  
- *  When the input and output sequences are the same, the scan is performed 
+ *  input operand in the partial sum. More precisely, <tt>*first</tt> is
+ *  assigned to <tt>*result</tt> and the sum of <tt>*first</tt> and
+ *  <tt>*(first + 1)</tt> is assigned to <tt>*(result + 1)</tt>, and so on.
+ *  This version of \p inclusive_scan assumes plus as the associative operator.
+ *  When the input and output sequences are the same, the scan is performed
  *  in-place.
  *
  *  \p inclusive_scan is similar to \c std::partial_sum in the STL.  The primary
  *  difference between the two functions is that \c std::partial_sum guarantees
- *  a serial summation order, while \p inclusive_scan requires associativity of 
+ *  a serial summation order, while \p inclusive_scan requires associativity of
  *  the binary operation to parallelize the prefix sum.
  *
  *  Results are not deterministic for pseudo-associative operators (e.g.,
@@ -140,7 +148,7 @@ __host__ __device__
  *
  *  \code
  *  #include <thrust/scan.h>
- *  
+ *
  *  int data[6] = {1, 0, 2, 2, 1, 3};
  *
  *  thrust::inclusive_scan(data, data + 6, data); // in-place scan
@@ -160,12 +168,12 @@ template<typename InputIterator,
 
 /*! \p inclusive_scan computes an inclusive prefix sum operation. The
  *  term 'inclusive' means that each result includes the corresponding
- *  input operand in the partial sum.  When the input and output sequences 
+ *  input operand in the partial sum.  When the input and output sequences
  *  are the same, the scan is performed in-place.
  *
  *  \p inclusive_scan is similar to \c std::partial_sum in the STL.  The primary
  *  difference between the two functions is that \c std::partial_sum guarantees
- *  a serial summation order, while \p inclusive_scan requires associativity of 
+ *  a serial summation order, while \p inclusive_scan requires associativity of
  *  the binary operation to parallelize the prefix sum.
  *
  *  Results are not deterministic for pseudo-associative operators (e.g.,
@@ -200,7 +208,7 @@ template<typename InputIterator,
  *
  *  \code
  *  int data[10] = {-5, 0, 2, -3, 2, 4, 0, -1, 2, 8};
- * 
+ *
  *  thrust::maximum<int> binary_op;
  *
  *  thrust::inclusive_scan(thrust::host, data, data + 10, data, binary_op); // in-place scan
@@ -224,12 +232,12 @@ __host__ __device__
 
 /*! \p inclusive_scan computes an inclusive prefix sum operation. The
  *  term 'inclusive' means that each result includes the corresponding
- *  input operand in the partial sum.  When the input and output sequences 
+ *  input operand in the partial sum.  When the input and output sequences
  *  are the same, the scan is performed in-place.
- *    
+ *
  *  \p inclusive_scan is similar to \c std::partial_sum in the STL.  The primary
  *  difference between the two functions is that \c std::partial_sum guarantees
- *  a serial summation order, while \p inclusive_scan requires associativity of 
+ *  a serial summation order, while \p inclusive_scan requires associativity of
  *  the binary operation to parallelize the prefix sum.
  *
  *  Results are not deterministic for pseudo-associative operators (e.g.,
@@ -259,7 +267,7 @@ __host__ __device__
  *
  *  \code
  *  int data[10] = {-5, 0, 2, -3, 2, 4, 0, -1, 2, 8};
- * 
+ *
  *  thrust::maximum<int> binary_op;
  *
  *  thrust::inclusive_scan(data, data + 10, data, binary_op); // in-place scan
@@ -279,12 +287,12 @@ template<typename InputIterator,
 
 
 /*! \p exclusive_scan computes an exclusive prefix sum operation. The
- *  term 'exclusive' means that each result does not include the 
+ *  term 'exclusive' means that each result does not include the
  *  corresponding input operand in the partial sum.  More precisely,
- *  <tt>0</tt> is assigned to <tt>*result</tt> and the sum of 
+ *  <tt>0</tt> is assigned to <tt>*result</tt> and the sum of
  *  <tt>0</tt> and <tt>*first</tt> is assigned to <tt>*(result + 1)</tt>,
- *  and so on. This version of \p exclusive_scan assumes plus as the 
- *  associative operator and \c 0 as the initial value.  When the input and 
+ *  and so on. This version of \p exclusive_scan assumes plus as the
+ *  associative operator and \c 0 as the initial value.  When the input and
  *  output sequences are the same, the scan is performed in-place.
  *
  *  Results are not deterministic for pseudo-associative operators (e.g.,
@@ -292,7 +300,7 @@ template<typename InputIterator,
  *  operators may vary from run to run.
  *
  *  The algorithm's execution is parallelized as determined by \p exec.
- *    
+ *
  *  \param exec The execution policy to use for parallelization.
  *  \param first The beginning of the input sequence.
  *  \param last The end of the input sequence.
@@ -318,7 +326,7 @@ template<typename InputIterator,
  *  #include <thrust/scan.h>
  *  #include <thrust/execution_policy.h>
  *  ...
- *  
+ *
  *  int data[6] = {1, 0, 2, 2, 1, 3};
  *
  *  thrust::exclusive_scan(thrust::host, data, data + 6, data); // in-place scan
@@ -339,12 +347,12 @@ __host__ __device__
 
 
 /*! \p exclusive_scan computes an exclusive prefix sum operation. The
- *  term 'exclusive' means that each result does not include the 
+ *  term 'exclusive' means that each result does not include the
  *  corresponding input operand in the partial sum.  More precisely,
- *  <tt>0</tt> is assigned to <tt>*result</tt> and the sum of 
+ *  <tt>0</tt> is assigned to <tt>*result</tt> and the sum of
  *  <tt>0</tt> and <tt>*first</tt> is assigned to <tt>*(result + 1)</tt>,
- *  and so on. This version of \p exclusive_scan assumes plus as the 
- *  associative operator and \c 0 as the initial value.  When the input and 
+ *  and so on. This version of \p exclusive_scan assumes plus as the
+ *  associative operator and \c 0 as the initial value.  When the input and
  *  output sequences are the same, the scan is performed in-place.
  *
  *  Results are not deterministic for pseudo-associative operators (e.g.,
@@ -371,7 +379,7 @@ __host__ __device__
  *
  *  \code
  *  #include <thrust/scan.h>
- *  
+ *
  *  int data[6] = {1, 0, 2, 2, 1, 3};
  *
  *  thrust::exclusive_scan(data, data + 6, data); // in-place scan
@@ -389,12 +397,12 @@ template<typename InputIterator,
 
 
 /*! \p exclusive_scan computes an exclusive prefix sum operation. The
- *  term 'exclusive' means that each result does not include the 
+ *  term 'exclusive' means that each result does not include the
  *  corresponding input operand in the partial sum.  More precisely,
- *  \p init is assigned to <tt>*result</tt> and the sum of \p init and 
- *  <tt>*first</tt> is assigned to <tt>*(result + 1)</tt>, and so on. 
- *  This version of \p exclusive_scan assumes plus as the associative 
- *  operator but requires an initial value \p init.  When the input and 
+ *  \p init is assigned to <tt>*result</tt> and the sum of \p init and
+ *  <tt>*first</tt> is assigned to <tt>*(result + 1)</tt>, and so on.
+ *  This version of \p exclusive_scan assumes plus as the associative
+ *  operator but requires an initial value \p init.  When the input and
  *  output sequences are the same, the scan is performed in-place.
  *
  *  Results are not deterministic for pseudo-associative operators (e.g.,
@@ -427,7 +435,7 @@ template<typename InputIterator,
  *  \code
  *  #include <thrust/scan.h>
  *  #include <thrust/execution_policy.h>
- *  
+ *
  *  int data[6] = {1, 0, 2, 2, 1, 3};
  *
  *  thrust::exclusive_scan(thrust::host, data, data + 6, data, 4); // in-place scan
@@ -450,12 +458,12 @@ __host__ __device__
 
 
 /*! \p exclusive_scan computes an exclusive prefix sum operation. The
- *  term 'exclusive' means that each result does not include the 
+ *  term 'exclusive' means that each result does not include the
  *  corresponding input operand in the partial sum.  More precisely,
- *  \p init is assigned to <tt>*result</tt> and the sum of \p init and 
- *  <tt>*first</tt> is assigned to <tt>*(result + 1)</tt>, and so on. 
- *  This version of \p exclusive_scan assumes plus as the associative 
- *  operator but requires an initial value \p init.  When the input and 
+ *  \p init is assigned to <tt>*result</tt> and the sum of \p init and
+ *  <tt>*first</tt> is assigned to <tt>*(result + 1)</tt>, and so on.
+ *  This version of \p exclusive_scan assumes plus as the associative
+ *  operator but requires an initial value \p init.  When the input and
  *  output sequences are the same, the scan is performed in-place.
  *
  *  Results are not deterministic for pseudo-associative operators (e.g.,
@@ -482,7 +490,7 @@ __host__ __device__
  *
  *  \code
  *  #include <thrust/scan.h>
- *  
+ *
  *  int data[6] = {1, 0, 2, 2, 1, 3};
  *
  *  thrust::exclusive_scan(data, data + 6, data, 4); // in-place scan
@@ -502,11 +510,11 @@ template<typename InputIterator,
 
 
 /*! \p exclusive_scan computes an exclusive prefix sum operation. The
- *  term 'exclusive' means that each result does not include the 
+ *  term 'exclusive' means that each result does not include the
  *  corresponding input operand in the partial sum.  More precisely,
  *  \p init is assigned to <tt>\*result</tt> and the value
  *  <tt>binary_op(init, \*first)</tt> is assigned to <tt>\*(result + 1)</tt>,
- *  and so on. This version of the function requires both an associative 
+ *  and so on. This version of the function requires both an associative
  *  operator and an initial value \p init.  When the input and output
  *  sequences are the same, the scan is performed in-place.
  *
@@ -515,7 +523,7 @@ template<typename InputIterator,
  *  operators may vary from run to run.
  *
  *  The algorithm's execution is parallelized as determined by \p exec.
- *    
+ *
  *  \param exec The execution policy to use for parallelization.
  *  \param first The beginning of the input sequence.
  *  \param last The end of the input sequence.
@@ -547,16 +555,16 @@ template<typename InputIterator,
  *  #include <thrust/functional.h>
  *  #include <thrust/execution_policy.h>
  *  ...
- *  
+ *
  *  int data[10] = {-5, 0, 2, -3, 2, 4, 0, -1, 2, 8};
- * 
+ *
  *  thrust::maximum<int> binary_op;
  *
  *  thrust::exclusive_scan(thrust::host, data, data + 10, data, 1, binary_op); // in-place scan
  *
  *  // data is now {1, 1, 1, 2, 2, 2, 4, 4, 4, 4 }
  *  \endcode
- *  
+ *
  *  \see https://en.cppreference.com/w/cpp/algorithm/partial_sum
  */
 template<typename DerivedPolicy,
@@ -574,11 +582,11 @@ __host__ __device__
 
 
 /*! \p exclusive_scan computes an exclusive prefix sum operation. The
- *  term 'exclusive' means that each result does not include the 
+ *  term 'exclusive' means that each result does not include the
  *  corresponding input operand in the partial sum.  More precisely,
  *  \p init is assigned to <tt>\*result</tt> and the value
  *  <tt>binary_op(init, \*first)</tt> is assigned to <tt>\*(result + 1)</tt>,
- *  and so on. This version of the function requires both an associative 
+ *  and so on. This version of the function requires both an associative
  *  operator and an initial value \p init.  When the input and output
  *  sequences are the same, the scan is performed in-place.
  *
@@ -612,16 +620,16 @@ __host__ __device__
  *  \code
  *  #include <thrust/scan.h>
  *  #include <thrust/functional.h>
- *  
+ *
  *  int data[10] = {-5, 0, 2, -3, 2, 4, 0, -1, 2, 8};
- * 
+ *
  *  thrust::maximum<int> binary_op;
  *
  *  thrust::exclusive_scan(data, data + 10, data, 1, binary_op); // in-place scan
  *
  *  // data is now {1, 1, 1, 2, 2, 2, 4, 4, 4, 4 }
  *  \endcode
- *  
+ *
  *  \see https://en.cppreference.com/w/cpp/algorithm/partial_sum
  */
 template<typename InputIterator,
@@ -641,8 +649,8 @@ template<typename InputIterator,
  */
 
 
-/*! \p inclusive_scan_by_key computes an inclusive key-value or 'segmented' prefix 
- *  sum operation. The term 'inclusive' means that each result includes 
+/*! \p inclusive_scan_by_key computes an inclusive key-value or 'segmented' prefix
+ *  sum operation. The term 'inclusive' means that each result includes
  *  the corresponding input operand in the partial sum. The term 'segmented'
  *  means that the partial sums are broken into distinct segments.  In other
  *  words, within each segment a separate inclusive scan operation is computed.
@@ -676,7 +684,7 @@ template<typename InputIterator,
  *  \tparam InputIterator2 is a model of <a href="https://en.cppreference.com/w/cpp/iterator/input_iterator">Input Iterator</a>
  *                         and \c InputIterator2's \c value_type is convertible to \c OutputIterator's \c value_type.
  *  \tparam OutputIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/output_iterator">Output Iterator</a>,
- *                         and if \c x and \c y are objects of \c OutputIterator's \c value_type, then 
+ *                         and if \c x and \c y are objects of \c OutputIterator's \c value_type, then
  *                         <tt>binary_op(x,y)</tt> is defined.
  *
  *  \pre \p first1 may equal \p result but the range <tt>[first1, last1)</tt> and the range <tt>[result, result + (last1 - first1))</tt> shall not overlap otherwise.
@@ -689,7 +697,7 @@ template<typename InputIterator,
  *  #include <thrust/scan.h>
  *  #include <thrust/execution_policy.h>
  *  ...
- *  
+ *
  *  int data[10] = {1, 1, 1, 1, 1, 1, 1, 1, 1, 1};
  *  int keys[10] = {0, 0, 0, 1, 1, 2, 3, 3, 3, 3};
  *
@@ -712,10 +720,10 @@ __host__ __device__
                                        InputIterator1 last1,
                                        InputIterator2 first2,
                                        OutputIterator result);
- 
 
-/*! \p inclusive_scan_by_key computes an inclusive key-value or 'segmented' prefix 
- *  sum operation. The term 'inclusive' means that each result includes 
+
+/*! \p inclusive_scan_by_key computes an inclusive key-value or 'segmented' prefix
+ *  sum operation. The term 'inclusive' means that each result includes
  *  the corresponding input operand in the partial sum. The term 'segmented'
  *  means that the partial sums are broken into distinct segments.  In other
  *  words, within each segment a separate inclusive scan operation is computed.
@@ -745,7 +753,7 @@ __host__ __device__
  *  \tparam InputIterator2 is a model of <a href="https://en.cppreference.com/w/cpp/iterator/input_iterator">Input Iterator</a>
  *                         and \c InputIterator2's \c value_type is convertible to \c OutputIterator's \c value_type.
  *  \tparam OutputIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/output_iterator">Output Iterator</a>,
- *                         and if \c x and \c y are objects of \c OutputIterator's \c value_type, then 
+ *                         and if \c x and \c y are objects of \c OutputIterator's \c value_type, then
  *                         <tt>binary_op(x,y)</tt> is defined.
  *
  *  \pre \p first1 may equal \p result but the range <tt>[first1, last1)</tt> and the range <tt>[result, result + (last1 - first1))</tt> shall not overlap otherwise.
@@ -755,7 +763,7 @@ __host__ __device__
  *
  *  \code
  *  #include <thrust/scan.h>
- *  
+ *
  *  int data[10] = {1, 1, 1, 1, 1, 1, 1, 1, 1, 1};
  *  int keys[10] = {0, 0, 0, 1, 1, 2, 3, 3, 3, 3};
  *
@@ -777,17 +785,17 @@ template<typename InputIterator1,
                                        OutputIterator result);
 
 
-/*! \p inclusive_scan_by_key computes an inclusive key-value or 'segmented' prefix 
- *  sum operation. The term 'inclusive' means that each result includes 
+/*! \p inclusive_scan_by_key computes an inclusive key-value or 'segmented' prefix
+ *  sum operation. The term 'inclusive' means that each result includes
  *  the corresponding input operand in the partial sum. The term 'segmented'
  *  means that the partial sums are broken into distinct segments.  In other
  *  words, within each segment a separate inclusive scan operation is computed.
  *  Refer to the code sample below for example usage.
  *
- *  This version of \p inclusive_scan_by_key uses the binary predicate 
+ *  This version of \p inclusive_scan_by_key uses the binary predicate
  *  \c pred to compare adjacent keys.  Specifically, consecutive iterators
  *  <tt>i</tt> and <tt>i+1</tt> in the range <tt>[first1, last1)</tt>
- *  belong to the same segment if <tt>binary_pred(*i, *(i+1))</tt> is true, and belong to 
+ *  belong to the same segment if <tt>binary_pred(*i, *(i+1))</tt> is true, and belong to
  *  different segments otherwise.
  *
  *  This version of \p inclusive_scan_by_key assumes \c plus as the associative
@@ -798,7 +806,7 @@ template<typename InputIterator1,
  *  addition of floating-point types). Results for pseudo-associative
  *  operators may vary from run to run.
  *
- *  The algorithm's execution is parallelized as determined by \p exec. 
+ *  The algorithm's execution is parallelized as determined by \p exec.
  *
  *  \param exec The execution policy to use for parallelization.
  *  \param first1 The beginning of the key sequence.
@@ -813,7 +821,7 @@ template<typename InputIterator1,
  *  \tparam InputIterator2 is a model of <a href="https://en.cppreference.com/w/cpp/iterator/input_iterator">Input Iterator</a>
  *                         and \c InputIterator2's \c value_type is convertible to \c OutputIterator's \c value_type.
  *  \tparam OutputIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/output_iterator">Output Iterator</a>,
- *                         and if \c x and \c y are objects of \c OutputIterator's \c value_type, then 
+ *                         and if \c x and \c y are objects of \c OutputIterator's \c value_type, then
  *                         <tt>binary_op(x,y)</tt> is defined.
  *  \tparam BinaryPredicate is a model of <a href="https://en.cppreference.com/w/cpp/named_req/BinaryPredicate">Binary Predicate</a>.
  *
@@ -828,7 +836,7 @@ template<typename InputIterator1,
  *  #include <thrust/functional.h>
  *  #include <thrust/execution_policy.h>
  *  ...
- *  
+ *
  *  int data[10] = {1, 1, 1, 1, 1, 1, 1, 1, 1, 1};
  *  int keys[10] = {0, 0, 0, 1, 1, 2, 3, 3, 3, 3};
  *
@@ -857,17 +865,17 @@ __host__ __device__
                                        BinaryPredicate binary_pred);
 
 
-/*! \p inclusive_scan_by_key computes an inclusive key-value or 'segmented' prefix 
- *  sum operation. The term 'inclusive' means that each result includes 
+/*! \p inclusive_scan_by_key computes an inclusive key-value or 'segmented' prefix
+ *  sum operation. The term 'inclusive' means that each result includes
  *  the corresponding input operand in the partial sum. The term 'segmented'
  *  means that the partial sums are broken into distinct segments.  In other
  *  words, within each segment a separate inclusive scan operation is computed.
  *  Refer to the code sample below for example usage.
  *
- *  This version of \p inclusive_scan_by_key uses the binary predicate 
+ *  This version of \p inclusive_scan_by_key uses the binary predicate
  *  \c pred to compare adjacent keys.  Specifically, consecutive iterators
  *  <tt>i</tt> and <tt>i+1</tt> in the range <tt>[first1, last1)</tt>
- *  belong to the same segment if <tt>binary_pred(*i, *(i+1))</tt> is true, and belong to 
+ *  belong to the same segment if <tt>binary_pred(*i, *(i+1))</tt> is true, and belong to
  *  different segments otherwise.
  *
  *  This version of \p inclusive_scan_by_key assumes \c plus as the associative
@@ -889,7 +897,7 @@ __host__ __device__
  *  \tparam InputIterator2 is a model of <a href="https://en.cppreference.com/w/cpp/iterator/input_iterator">Input Iterator</a>
  *                         and \c InputIterator2's \c value_type is convertible to \c OutputIterator's \c value_type.
  *  \tparam OutputIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/output_iterator">Output Iterator</a>,
- *                         and if \c x and \c y are objects of \c OutputIterator's \c value_type, then 
+ *                         and if \c x and \c y are objects of \c OutputIterator's \c value_type, then
  *                         <tt>binary_op(x,y)</tt> is defined.
  *  \tparam BinaryPredicate is a model of <a href="https://en.cppreference.com/w/cpp/named_req/BinaryPredicate">Binary Predicate</a>.
  *
@@ -901,7 +909,7 @@ __host__ __device__
  *  \code
  *  #include <thrust/scan.h>
  *  #include <thrust/functional.h>
- *  
+ *
  *  int data[10] = {1, 1, 1, 1, 1, 1, 1, 1, 1, 1};
  *  int keys[10] = {0, 0, 0, 1, 1, 2, 3, 3, 3, 3};
  *
@@ -927,20 +935,20 @@ template<typename InputIterator1,
                                        BinaryPredicate binary_pred);
 
 
-/*! \p inclusive_scan_by_key computes an inclusive key-value or 'segmented' prefix 
- *  sum operation. The term 'inclusive' means that each result includes 
+/*! \p inclusive_scan_by_key computes an inclusive key-value or 'segmented' prefix
+ *  sum operation. The term 'inclusive' means that each result includes
  *  the corresponding input operand in the partial sum. The term 'segmented'
  *  means that the partial sums are broken into distinct segments.  In other
  *  words, within each segment a separate inclusive scan operation is computed.
  *  Refer to the code sample below for example usage.
  *
- *  This version of \p inclusive_scan_by_key uses the binary predicate 
+ *  This version of \p inclusive_scan_by_key uses the binary predicate
  *  \c pred to compare adjacent keys.  Specifically, consecutive iterators
  *  <tt>i</tt> and <tt>i+1</tt> in the range <tt>[first1, last1)</tt>
- *  belong to the same segment if <tt>binary_pred(*i, *(i+1))</tt> is true, and belong to 
+ *  belong to the same segment if <tt>binary_pred(*i, *(i+1))</tt> is true, and belong to
  *  different segments otherwise.
  *
- *  This version of \p inclusive_scan_by_key uses the associative operator 
+ *  This version of \p inclusive_scan_by_key uses the associative operator
  *  \c binary_op to perform the prefix sum. When the input and output sequences
  *  are the same, the scan is performed in-place.
  *
@@ -964,7 +972,7 @@ template<typename InputIterator1,
  *  \tparam InputIterator2 is a model of <a href="https://en.cppreference.com/w/cpp/iterator/input_iterator">Input Iterator</a>
  *                         and \c InputIterator2's \c value_type is convertible to \c OutputIterator's \c value_type.
  *  \tparam OutputIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/output_iterator">Output Iterator</a>,
- *                         and if \c x and \c y are objects of \c OutputIterator's \c value_type, then 
+ *                         and if \c x and \c y are objects of \c OutputIterator's \c value_type, then
  *                         <tt>binary_op(x,y)</tt> is defined.
  *  \tparam BinaryPredicate is a model of <a href="https://en.cppreference.com/w/cpp/named_req/BinaryPredicate">Binary Predicate</a>.
  *  \tparam AssociativeOperator is a model of <a href="https://en.cppreference.com/w/cpp/utility/functional/binary_function">Binary Function</a>
@@ -982,7 +990,7 @@ template<typename InputIterator1,
  *  #include <thrust/functional.h>
  *  #include <thrust/execution_policy.h>
  *  ...
- *  
+ *
  *  int data[10] = {1, 1, 1, 1, 1, 1, 1, 1, 1, 1};
  *  int keys[10] = {0, 0, 0, 1, 1, 2, 3, 3, 3, 3};
  *
@@ -1014,24 +1022,24 @@ __host__ __device__
                                        AssociativeOperator binary_op);
 
 
-/*! \p inclusive_scan_by_key computes an inclusive key-value or 'segmented' prefix 
- *  sum operation. The term 'inclusive' means that each result includes 
+/*! \p inclusive_scan_by_key computes an inclusive key-value or 'segmented' prefix
+ *  sum operation. The term 'inclusive' means that each result includes
  *  the corresponding input operand in the partial sum. The term 'segmented'
  *  means that the partial sums are broken into distinct segments.  In other
  *  words, within each segment a separate inclusive scan operation is computed.
  *  Refer to the code sample below for example usage.
  *
- *  This version of \p inclusive_scan_by_key uses the binary predicate 
+ *  This version of \p inclusive_scan_by_key uses the binary predicate
  *  \c pred to compare adjacent keys.  Specifically, consecutive iterators
  *  <tt>i</tt> and <tt>i+1</tt> in the range <tt>[first1, last1)</tt>
- *  belong to the same segment if <tt>binary_pred(*i, *(i+1))</tt> is true, and belong to 
+ *  belong to the same segment if <tt>binary_pred(*i, *(i+1))</tt> is true, and belong to
  *  different segments otherwise.
  *
  *  Results are not deterministic for pseudo-associative operators (e.g.,
  *  addition of floating-point types). Results for pseudo-associative
  *  operators may vary from run to run.
  *
- *  This version of \p inclusive_scan_by_key uses the associative operator 
+ *  This version of \p inclusive_scan_by_key uses the associative operator
  *  \c binary_op to perform the prefix sum. When the input and output sequences
  *  are the same, the scan is performed in-place.
  *
@@ -1047,7 +1055,7 @@ __host__ __device__
  *  \tparam InputIterator2 is a model of <a href="https://en.cppreference.com/w/cpp/iterator/input_iterator">Input Iterator</a>
  *                         and \c InputIterator2's \c value_type is convertible to \c OutputIterator's \c value_type.
  *  \tparam OutputIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/output_iterator">Output Iterator</a>,
- *                         and if \c x and \c y are objects of \c OutputIterator's \c value_type, then 
+ *                         and if \c x and \c y are objects of \c OutputIterator's \c value_type, then
  *                         <tt>binary_op(x,y)</tt> is defined.
  *  \tparam BinaryPredicate is a model of <a href="https://en.cppreference.com/w/cpp/named_req/BinaryPredicate">Binary Predicate</a>.
  *  \tparam AssociativeOperator is a model of <a href="https://en.cppreference.com/w/cpp/utility/functional/binary_function">Binary Function</a>
@@ -1062,7 +1070,7 @@ __host__ __device__
  *  \code
  *  #include <thrust/scan.h>
  *  #include <thrust/functional.h>
- *  
+ *
  *  int data[10] = {1, 1, 1, 1, 1, 1, 1, 1, 1, 1};
  *  int keys[10] = {0, 0, 0, 1, 1, 2, 3, 3, 3, 3};
  *
@@ -1091,7 +1099,7 @@ template<typename InputIterator1,
                                        AssociativeOperator binary_op);
 
 
-/*! \p exclusive_scan_by_key computes an exclusive segmented prefix 
+/*! \p exclusive_scan_by_key computes an exclusive segmented prefix
  *
  *  This version of \p exclusive_scan_by_key uses the value \c 0 to
  *  initialize the exclusive scan operation.
@@ -1099,11 +1107,11 @@ template<typename InputIterator1,
  *  This version of \p exclusive_scan_by_key assumes \c plus as the associative
  *  operator used to perform the prefix sum. When the input and output sequences
  *  are the same, the scan is performed in-place.
- * 
+ *
  *  This version of \p exclusive_scan_by_key assumes \c equal_to as the binary
  *  predicate used to compare adjacent keys.  Specifically, consecutive iterators
  *  <tt>i</tt> and <tt>i+1</tt> in the range <tt>[first1, last1</tt>
- *  belong to the same segment if <tt>*i == *(i+1)</tt>, and belong to 
+ *  belong to the same segment if <tt>*i == *(i+1)</tt>, and belong to
  *  different segments otherwise.
  *
  *  Results are not deterministic for pseudo-associative operators (e.g.,
@@ -1130,7 +1138,7 @@ template<typename InputIterator1,
  *  #include <thrust/scan.h>
  *  #include <thrust/execution_policy.h>
  *  ...
- *  
+ *
  *  int keys[10] = {0, 0, 0, 1, 1, 2, 3, 3, 3, 3};
  *  int vals[10] = {1, 1, 1, 1, 1, 1, 1, 1, 1, 1};
  *
@@ -1154,7 +1162,7 @@ __host__ __device__
                                        OutputIterator result);
 
 
-/*! \p exclusive_scan_by_key computes an exclusive segmented prefix 
+/*! \p exclusive_scan_by_key computes an exclusive segmented prefix
  *
  *  This version of \p exclusive_scan_by_key uses the value \c 0 to
  *  initialize the exclusive scan operation.
@@ -1162,11 +1170,11 @@ __host__ __device__
  *  This version of \p exclusive_scan_by_key assumes \c plus as the associative
  *  operator used to perform the prefix sum. When the input and output sequences
  *  are the same, the scan is performed in-place.
- * 
+ *
  *  This version of \p exclusive_scan_by_key assumes \c equal_to as the binary
  *  predicate used to compare adjacent keys.  Specifically, consecutive iterators
  *  <tt>i</tt> and <tt>i+1</tt> in the range <tt>[first1, last1</tt>
- *  belong to the same segment if <tt>*i == *(i+1)</tt>, and belong to 
+ *  belong to the same segment if <tt>*i == *(i+1)</tt>, and belong to
  *  different segments otherwise.
  *
  *  Results are not deterministic for pseudo-associative operators (e.g.,
@@ -1187,7 +1195,7 @@ __host__ __device__
  *
  *  \code
  *  #include <thrust/scan.h>
- *  
+ *
  *  int keys[10] = {0, 0, 0, 1, 1, 2, 3, 3, 3, 3};
  *  int vals[10] = {1, 1, 1, 1, 1, 1, 1, 1, 1, 1};
  *
@@ -1208,7 +1216,7 @@ template<typename InputIterator1,
                                        OutputIterator result);
 
 
-/*! \p exclusive_scan_by_key computes an exclusive key-value or 'segmented' prefix 
+/*! \p exclusive_scan_by_key computes an exclusive key-value or 'segmented' prefix
  *  sum operation. The term 'exclusive' means that each result does not include
  *  the corresponding input operand in the partial sum. The term 'segmented'
  *  means that the partial sums are broken into distinct segments.  In other
@@ -1243,7 +1251,7 @@ template<typename InputIterator1,
  *  #include <thrust/functional.h>
  *  #include <thrust/execution_policy.h>
  *  ...
- *  
+ *
  *  int keys[10] = {0, 0, 0, 1, 1, 2, 3, 3, 3, 3};
  *  int vals[10] = {1, 1, 1, 1, 1, 1, 1, 1, 1, 1};
  *
@@ -1272,7 +1280,7 @@ __host__ __device__
                                        T init);
 
 
-/*! \p exclusive_scan_by_key computes an exclusive key-value or 'segmented' prefix 
+/*! \p exclusive_scan_by_key computes an exclusive key-value or 'segmented' prefix
  *  sum operation. The term 'exclusive' means that each result does not include
  *  the corresponding input operand in the partial sum. The term 'segmented'
  *  means that the partial sums are broken into distinct segments.  In other
@@ -1301,7 +1309,7 @@ __host__ __device__
  *  \code
  *  #include <thrust/scan.h>
  *  #include <thrust/functional.h>
- *  
+ *
  *  int keys[10] = {0, 0, 0, 1, 1, 2, 3, 3, 3, 3};
  *  int vals[10] = {1, 1, 1, 1, 1, 1, 1, 1, 1, 1};
  *
@@ -1327,7 +1335,7 @@ template<typename InputIterator1,
                                        T init);
 
 
-/*! \p exclusive_scan_by_key computes an exclusive key-value or 'segmented' prefix 
+/*! \p exclusive_scan_by_key computes an exclusive key-value or 'segmented' prefix
  *  sum operation. The term 'exclusive' means that each result does not include
  *  the corresponding input operand in the partial sum. The term 'segmented'
  *  means that the partial sums are broken into distinct segments.  In other
@@ -1368,7 +1376,7 @@ template<typename InputIterator1,
  *  #include <thrust/functional.h>
  *  #include <thrust/execution_policy.h>
  *  ...
- *  
+ *
  *  int keys[10] = {0, 0, 0, 1, 1, 2, 3, 3, 3, 3};
  *  int vals[10] = {1, 1, 1, 1, 1, 1, 1, 1, 1, 1};
  *
@@ -1401,7 +1409,7 @@ __host__ __device__
                                        BinaryPredicate binary_pred);
 
 
-/*! \p exclusive_scan_by_key computes an exclusive key-value or 'segmented' prefix 
+/*! \p exclusive_scan_by_key computes an exclusive key-value or 'segmented' prefix
  *  sum operation. The term 'exclusive' means that each result does not include
  *  the corresponding input operand in the partial sum. The term 'segmented'
  *  means that the partial sums are broken into distinct segments.  In other
@@ -1436,7 +1444,7 @@ __host__ __device__
  *  \code
  *  #include <thrust/scan.h>
  *  #include <thrust/functional.h>
- *  
+ *
  *  int keys[10] = {0, 0, 0, 1, 1, 2, 3, 3, 3, 3};
  *  int vals[10] = {1, 1, 1, 1, 1, 1, 1, 1, 1, 1};
  *
@@ -1466,7 +1474,7 @@ template<typename InputIterator1,
                                        BinaryPredicate binary_pred);
 
 
-/*! \p exclusive_scan_by_key computes an exclusive key-value or 'segmented' prefix 
+/*! \p exclusive_scan_by_key computes an exclusive key-value or 'segmented' prefix
  *  sum operation. The term 'exclusive' means that each result does not include
  *  the corresponding input operand in the partial sum. The term 'segmented'
  *  means that the partial sums are broken into distinct segments.  In other
@@ -1478,10 +1486,10 @@ template<typename InputIterator1,
  *
  *  This version of \p exclusive_scan_by_key uses the binary predicate \c binary_pred
  *  to compare adjacent keys.  Specifically, consecutive iterators <tt>i</tt> and
- *  <tt>i+1</tt> in the range <tt>[first1, last1)</tt> belong to the same segment if 
+ *  <tt>i+1</tt> in the range <tt>[first1, last1)</tt> belong to the same segment if
  *  <tt>binary_pred(*i, *(i+1))</tt> is true, and belong to different segments otherwise.
  *
- *  This version of \p exclusive_scan_by_key uses the associative operator 
+ *  This version of \p exclusive_scan_by_key uses the associative operator
  *  \c binary_op to perform the prefix sum. When the input and output sequences
  *  are the same, the scan is performed in-place.
  *
@@ -1506,7 +1514,7 @@ template<typename InputIterator1,
  *  \tparam InputIterator2 is a model of <a href="https://en.cppreference.com/w/cpp/iterator/input_iterator">Input Iterator</a>
  *                         and \c InputIterator2's \c value_type is convertible to \c OutputIterator's \c value_type.
  *  \tparam OutputIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/output_iterator">Output Iterator</a>,
- *                         and if \c x and \c y are objects of \c OutputIterator's \c value_type, then 
+ *                         and if \c x and \c y are objects of \c OutputIterator's \c value_type, then
  *                         <tt>binary_op(x,y)</tt> is defined.
  *  \tparam T is convertible to \c OutputIterator's \c value_type.
  *  \tparam BinaryPredicate is a model of <a href="https://en.cppreference.com/w/cpp/named_req/BinaryPredicate">Binary Predicate</a>.
@@ -1524,7 +1532,7 @@ template<typename InputIterator1,
  *  #include <thrust/functional.h>
  *  #include <thrust/execution_policy.h>
  *  ...
- *  
+ *
  *  int keys[10] = {0, 0, 0, 1, 1, 2, 3, 3, 3, 3};
  *  int vals[10] = {1, 1, 1, 1, 1, 1, 1, 1, 1, 1};
  *
@@ -1560,7 +1568,7 @@ __host__ __device__
                                        AssociativeOperator binary_op);
 
 
-/*! \p exclusive_scan_by_key computes an exclusive key-value or 'segmented' prefix 
+/*! \p exclusive_scan_by_key computes an exclusive key-value or 'segmented' prefix
  *  sum operation. The term 'exclusive' means that each result does not include
  *  the corresponding input operand in the partial sum. The term 'segmented'
  *  means that the partial sums are broken into distinct segments.  In other
@@ -1572,10 +1580,10 @@ __host__ __device__
  *
  *  This version of \p exclusive_scan_by_key uses the binary predicate \c binary_pred
  *  to compare adjacent keys.  Specifically, consecutive iterators <tt>i</tt> and
- *  <tt>i+1</tt> in the range <tt>[first1, last1)</tt> belong to the same segment if 
+ *  <tt>i+1</tt> in the range <tt>[first1, last1)</tt> belong to the same segment if
  *  <tt>binary_pred(*i, *(i+1))</tt> is true, and belong to different segments otherwise.
  *
- *  This version of \p exclusive_scan_by_key uses the associative operator 
+ *  This version of \p exclusive_scan_by_key uses the associative operator
  *  \c binary_op to perform the prefix sum. When the input and output sequences
  *  are the same, the scan is performed in-place.
  *
@@ -1596,7 +1604,7 @@ __host__ __device__
  *  \tparam InputIterator2 is a model of <a href="https://en.cppreference.com/w/cpp/iterator/input_iterator">Input Iterator</a>
  *                         and \c InputIterator2's \c value_type is convertible to \c OutputIterator's \c value_type.
  *  \tparam OutputIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/output_iterator">Output Iterator</a>,
- *                         and if \c x and \c y are objects of \c OutputIterator's \c value_type, then 
+ *                         and if \c x and \c y are objects of \c OutputIterator's \c value_type, then
  *                         <tt>binary_op(x,y)</tt> is defined.
  *  \tparam T is convertible to \c OutputIterator's \c value_type.
  *  \tparam BinaryPredicate is a model of <a href="https://en.cppreference.com/w/cpp/named_req/BinaryPredicate">Binary Predicate</a>.
@@ -1611,7 +1619,7 @@ __host__ __device__
  *  \code
  *  #include <thrust/scan.h>
  *  #include <thrust/functional.h>
- *  
+ *
  *  int keys[10] = {0, 0, 0, 1, 1, 2, 3, 3, 3, 3};
  *  int vals[10] = {1, 1, 1, 1, 1, 1, 1, 1, 1, 1};
  *
