@@ -21,6 +21,14 @@
 #pragma once
 
 #include <thrust/detail/config.h>
+
+#if defined(_CCCL_IMPLICIT_SYSTEM_HEADER_GCC)
+#  pragma GCC system_header
+#elif defined(_CCCL_IMPLICIT_SYSTEM_HEADER_CLANG)
+#  pragma clang system_header
+#elif defined(_CCCL_IMPLICIT_SYSTEM_HEADER_MSVC)
+#  pragma system_header
+#endif // no system header
 #include <cstring>
 #include <thrust/system/detail/sequential/general_copy.h>
 
@@ -41,6 +49,13 @@ __host__ __device__
                     std::ptrdiff_t n,
                     T *result)
 {
+  if (n == 0)
+  {
+    // If `first` or `result` is an invalid pointer, 
+    // the behavior of `std::memmove` is undefined, even if `n` is zero. 
+    return result;
+  }
+
   T* return_value = NULL;
 
   NV_IF_TARGET(NV_IS_HOST, (
